/**
 * Base64 encoding and decoding with a given charset and optional padding.
 * This class can be used to create base64 encoders and decoders with custom charsets.
 * @module base64/encoding
 */
export declare class Encoding {
    private _charset;
    private _noPadding;
    private _valid;
    /**
     *
     * @param charset Charset to use for base64 encoding. This must be 64-characters long.
     * @param noPadding If true, encoded strings won't include padding.
     */
    constructor(charset: string, noPadding?: boolean);
    /**
     * Encode an ArrayBuffer to base64 in a string.
     * @param ab Data to encode to base64
     * @returns Base64-encoded string
     */
    Encode(ab: ArrayBuffer): string;
    /**
     * Decode a string from base64. Padding is always optional.
     * @param str Base64-encoded string
     * @returns Data decoded from the base64 string
     */
    Decode(str: string): ArrayBuffer;
}
