/**
 * This module provides utilities to encode and decode base64 using the "standard" encoding, where characters 63 and 64 are `+` and `/` respectively. The `Encode` function appends padding `=` characters at the end of the encoded string, if required (with `Decode`, padding is always optional).
 * @module base64/standard
 */
/**
 * Encode an ArrayBuffer to base64 in a string, using base64 "standard" encoding.
 * @param ab Data to encode to base64
 * @returns Base64-encoded string
 */
export declare function Encode(ab: ArrayBuffer): string;
/**
 * Decode a string from base64, using base64 "standard" encoding. Padding is always optional.
 * @param str Base64-encoded string
 * @returns Data decoded from the base64 string
 */
export declare function Decode(str: string): ArrayBuffer;
